==> ejc-outcontract-impl-3.0.0-20251015.093617-355-sources.jar: com/ejianc/foundation/sealApproval/service/impl/SealApprovalBpmServiceImpl.java <==
package com.ejianc.foundation.sealApproval.service.impl;

import java.util.Date;

import com.ejianc.foundation.sealApproval.service.IZjkjTianJianSyncService;
import com.ejianc.framework.auth.session.SessionManager;
import org.apache.ibatis.plugin.Invocation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.sealApproval.bean.SealApprovalEntity;
import com.ejianc.foundation.sealApproval.service.ISealApprovalService;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("sealApproval") 
public class SealApprovalBpmServiceImpl implements ICommonBusinessService {
	
	
    @Autowired
    private ISealApprovalService sealApprovalService;
    @Autowired
    private IZjkjTianJianSyncService zjkjTianJianSyncService;
	@Autowired
	private SessionManager sessionManager;
	
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		SealApprovalEntity entity = sealApprovalService.selectById(billId);
		entity.setSubmiter(sessionManager.getUserContext().getUserName());
		entity.setSubmitDate(new Date());
		sealApprovalService.saveOrUpdate(entity);
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		SealApprovalEntity entity = sealApprovalService.selectById(billId);
		if(entity!=null){
			entity.setPrintState("0");
			entity.setApplyDate(new Date());
			if(state == 1){
				entity.setSubmiter(sessionManager.getUserContext().getUserName());
				entity.setSubmitDate(new Date());
			}
			sealApprovalService.saveOrUpdate(entity, false);
			//调用天鉴系统接口
			zjkjTianJianSyncService.syncSeal(billId);
		}

		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}

==> ejc-outcontract-impl-3.0.0-20251106.025133-392-sources.jar: com/ejianc/foundation/sealApproval/service/impl/SealApprovalBpmServiceImpl.java <==
package com.ejianc.foundation.sealApproval.service.impl;

import java.util.Date;

import com.ejianc.foundation.sealApproval.service.IZjkjTianJianSyncService;
import com.ejianc.framework.auth.session.SessionManager;
import org.apache.ibatis.plugin.Invocation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.sealApproval.bean.SealApprovalEntity;
import com.ejianc.foundation.sealApproval.service.ISealApprovalService;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("sealApproval") 
public class SealApprovalBpmServiceImpl implements ICommonBusinessService {
	
	
    @Autowired
    private ISealApprovalService sealApprovalService;
    @Autowired
    private IZjkjTianJianSyncService zjkjTianJianSyncService;
	@Autowired
	private SessionManager sessionManager;
	
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		SealApprovalEntity entity = sealApprovalService.selectById(billId);
		entity.setSubmiter(sessionManager.getUserContext().getUserName());
		entity.setSubmitDate(new Date());
		sealApprovalService.saveOrUpdate(entity);
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		SealApprovalEntity entity = sealApprovalService.selectById(billId);
		if(entity!=null){
			entity.setPrintState("0");
			entity.setApplyDate(new Date());
			if(state == 1){
				entity.setSubmiter(sessionManager.getUserContext().getUserName());
				entity.setSubmitDate(new Date());
			}
			sealApprovalService.saveOrUpdate(entity, false);
//			//调用天鉴系统接口
//			zjkjTianJianSyncService.syncSeal(billId);
		}

		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}
